/*
	Advanved Dialogs v1.0.7
	Copyright (C) 2005-2008 Jonas Gehring

	Advanced Dialogs is free software; you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Advanced Dialogs is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// C Source File
// Created 17.01.2006; 06:44:40


#include <gray.h>

#include "AdvDialogs.h"							// This should be obvious ;)


// Frees a Bitmap
void FreeBitmap(ADVBITMAP *bitmap)
{
	free(bitmap->data);
	free(bitmap);
}


// Creates a new Bitmap
ADVBITMAP *AdvDlgBitmapNew(short width, short height, const unsigned char *lpdata, const unsigned char *dpdata)
{
	ADVBITMAP *bitmap;
	short size = (height*width) >> 3;

	// Allocate space
	if ((bitmap = malloc(sizeof(ADVBITMAP))) == NULL)
	{
		return NULL;
	}
	if ((bitmap->data = malloc((BITMAP_HDR_SIZE + size)*2)) == NULL)
	{
		free(bitmap);
		return NULL;
	}
	
	BITMAP *t = (BITMAP *)((char*)bitmap->data + BITMAP_HDR_SIZE + size);

	t->NumRows = bitmap->data->NumRows = height;
	t->NumCols = bitmap->data->NumCols = width;
	
	memcpy(bitmap->data->Data, lpdata, size);
	memcpy(t->Data, dpdata, size);

	return bitmap;
}


// Draws a Bitmap
void DrawBitmap(ADVDIALOG *dialog, ADVBITMAP *bitmap)
{
	// Draw Light Plane contents
	GraySetAMSPlane(LIGHT_PLANE);
	BitmapPut((dialog->left_x + bitmap->x), (dialog->top_y + bitmap->y),
			   bitmap->data,
			   &(SCR_RECT){{dialog->left_x, dialog->top_y, dialog->right_x, dialog->bottom_y}},
			   A_REPLACE);
			   
	// Draw Dark Plane contents
	GraySetAMSPlane(DARK_PLANE);
	BitmapPut((dialog->left_x + bitmap->x), (dialog->top_y + bitmap->y),
			   (BITMAP *)((char*)bitmap->data + BITMAP_HDR_SIZE + ((bitmap->data->NumRows*bitmap->data->NumCols) >> 3)),
			   &(SCR_RECT){{dialog->left_x, dialog->top_y, dialog->right_x, dialog->bottom_y}},
			   A_REPLACE);

}

